/* common.h */

/*
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 by
 *	University of New Hampshire Interoperability Laboratory
 *	121 Technology Drive, Suite 2
 *	Durham, NH 03824-4716
 *	phone: 1-603-862-0090
 *	fax: 1-603-862-4181
 *	e-mail: info@iol.unh.edu
 * All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING.GPL in the main directory of this source tree, or the
 * BSD license, available from the file COPYING.BSD in the main directory
 * of this source tree.
 *
 * This material is based upon work supported by the National Science
 * Foundation under Grant No. OCI-1127228.
 *
 * Any opinions, findings, and conclusions or recommendations
 * expressed in this material are those of the authors and do not
 * necessarily reflect the views of the National Science Foundation.
 */

#include "utilities.h"

#define TEXT_SIZE	1024			/* size of text buffer */


#define ADDRESS_ITEMS	1
#define ACCEPT_ITEMS	1
#define ACCEPT_DEPTH	1
#define SEND_DEPTH	2
#define RECV_DEPTH	2

#define MEGA_UNITS      (1000000.0)


#define OPTIONS		"a:A:p:P:c:C:s:S:hHdDb:B:uUm:M:F:nNkKxXEr:R:"
#define WHITE_SPACE	" \t\n\r\f\v"
#define DEFAULT_PORT	"54321"
#define DEFAULT_COUNT	16
#define DEFAULT_SIZE	256
#define DEFAULT_NBUFS	1

extern exs_qhandle_t	send_queue;
extern exs_qhandle_t	recv_queue;
extern exs_mhandle_t	in_handle;
extern exs_mhandle_t	out_handle;

extern struct timespec	start_time;
extern struct sockaddr_in6	server_addr;
extern struct sockaddr_in6	client_addr;


/*	-a: server_name == IP address of server	*/
extern char			*server_name;

/*	-b: nbufs == number of simultaneously active buffers	*/
extern int			nbufs;

/*	-c: count == number of transactions	*/
extern int			count;

/*	-g: sg_elements == number of scatter_gather elements in exs_sendfile()*/
extern int			sg_elements;

/*	-p: server_port == port number of server */
extern char			*server_port;

/*	-s: size == number of bytes per transaction	*/
extern int			size;

/*	-u: unregistered_buffers_flag = 1 to use unregistered buffers for I/O */
extern int			unregistered_buffers_flag;

/*	Currently not used
 */
extern int			recv_flags;

/*	Currently not used
 */
extern int			send_flags;

/*	-k: set EXS_FD_SP_COPY_UNREG_ON_SEND
 *				to copy immediate data into prereg buf
 *	-x: set EXS_FD_BYPASS_PARAM_CHECKING to skip exs_xxx parameter checks
 *	-m: small_packet_max_size = maximum size of immediate data
 *	-F: completion thread CPU */
extern struct conn_params	our_conn_params;

/* non-zero to use registered memory (default) */
extern int use_registered_memory;


extern char *out_mess;
extern char *in_mess;


void print_latency( char *who, int count, int secs, int usecs );

extern void
startup( int argc, char *argv[], int is_client );

extern char *
time_prefix(void);


/* vi: set autoindent tabstop=8 shiftwidth=8 : */
